@@ -1,7 +1,9 @@
 package aeos;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: aeos.pm.in 3689 2017-06-29 21:50:09Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package aeos;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -59,7 +67,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.7;
 
 our $found_env;
 our $found_version;
@@ -138,7 +146,7 @@ sub ShowVersion {
 
     while (<$INPUT>) {
 	tr/\015//d;
-	if (/^$prompt/) {$found_version = 1; last};
+	if (/^$prompt/) { $found_version = 1; last};
 	next if (/^(\s*|\s*$cmd\s*)$/);
 	return(1) if /^% Invalid input/;
 	return(0) if ($found_version);		# Only do this routine once
@@ -146,12 +154,12 @@ sub ShowVersion {
 	next if (/uptime is/);			# Older AOS show uptime
         my($key, $val) = split(/:\s+/, $_, 2);
         if (! $val) {
-	    # Must be the model name if there's no colon
-	    ProcessHistory("COMMENTS", "", "", "!Model: $_" );
-	    next;
+           # Must be the model name if there's no colon
+           ProcessHistory("COMMENTS", "", "", "!Model: $_" );
+           next;
         }
         if ($key ne 'Uptime' and $key ne 'Free memory') {
-	    ProcessHistory("COMMENTS", "", "", "!$key: $val" );
+           ProcessHistory("COMMENTS", "", "", "!$key: $val" );
         }
     }
     return(0);
@@ -183,11 +191,11 @@ sub DiffConfig {
 sub ShowEnv {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowEnv: $_" if ($debug);
-    my($fans, $E0) = (0, undef);
+    my($fans, $supplies, $E0) = (0, 0, undef);
 
     while (<$INPUT>) {
 	tr/\015//d;
-	if (/^$prompt/) {$found_env = 1; last};
+	if (/^$prompt/) { $found_env = 1; last};
 	next if (/^(\s*|\s*$cmd\s*)$/);
 	return(1) if /^% Invalid input/;
 	return(0) if ($found_env);		# Only do this routine once
@@ -198,25 +206,19 @@ sub ShowEnv {
 	}
         /^(System \S+ status is|Action on overheat|Airflow)/ &&
 	    ProcessHistory("COMMENTS","keysort","E0","!$_") && next;
-        if (/^Fan\s+Status\s+/) {
-	    $fans = 1;
-	    next;
+        if ( /^Fan\s+Status\s+/ ) {
+            $fans = 1;
+            next;
         }
         $fans && /^\s*(\d+)\s+(\S+)/ &&
-	    ProcessHistory("COMMENTS","keysort","E1","!Fan $1: $2\n") && next;
-        if (/^supply\s+model\s+capacity/i) {
-	    while (<$INPUT>) {
-		tr/\015//d;
-		last if (/^\s*/);
-		if (/^$prompt/) {$found_version = 1; last};
-		/^\s*(\d+)\s+(\S+)\s+(\S+)\s+\S+\s+\S+\s+\S+\s+(\S+)/ &&
-		    ProcessHistory("COMMENTS","keysort","E2","!Power Supply $1: $2 $3 $4\n");
-		    next;
-		/^\s*Total\s+\S+\s+(\S+)\s+/ &&
-		    ProcessHistory("COMMENTS","keysort","E2","!Power Total: $1\n") &&
-		    next;;
-	    }
+            ProcessHistory("COMMENTS","keysort","E1","!Fan $1: $2\n") && next;
+        if ( /^Supply\s+Model\s+Capacity/ ) {
+            $fans = 0;
+            $supplies = 1;
+            next;
         }
+        $supplies && /^\s*(\d+)\s+(\S+)\s+(\S+)\s+\S+\s+\S+\s+\S+\s+(.+)/ &&
+            ProcessHistory("COMMENTS","keysort","E2","!Power Supply $1: $2 $3 $4\n" ) && next;
     }
     ProcessHistory("COMMENTS","","","!\n");
     return(0);
@@ -253,8 +255,8 @@ sub ShowBootExt {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^(\s*|\s*$cmd\s*)$/);
-	return(1) if (/^% Invalid input/);
-        return(0) if (/^% Error displaying /);
+	return(1) if /^% Invalid input/;
+        return(0) if /^% Error displaying /;
 
 	if (!defined($C0)) {
 	    $C0 = 1; ProcessHistory("COMMENTS","","","!\n");
@@ -301,8 +303,6 @@ sub ShowFlash {
         # persist changes constantly if you're running ntp, so
         # skip its updates.
         /\spersist$/ && next;
-	# frequent timestamp changes
-	/\sdebug$/ && next;
 
 	# Scheduled commands can cause free space to constantly
 	# change.  Even the trick of summarizing the free space
