@@ -1,7 +1,9 @@
 package arbor;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: arbor.pm.in 3729 2017-09-15 17:02:29Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package arbor;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -54,7 +62,7 @@ use warnings;
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.7;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -65,8 +73,6 @@ sub import {
     # Seems that it might also support "dumb".
     $ENV{'TERM'} = "vt100";
 
-    $timeo = 240;			# anlogin timeout in seconds
-
     0;
 }
 
@@ -91,7 +97,7 @@ TOP: while(<$INPUT>) {
 	if (/^Error:/) {
 	    print STDOUT ("$host anlogin error: $_");
 	    print STDERR ("$host anlogin error: $_") if ($debug);
-	    $clean_run = 0;
+	    $clean_run=0;
 	    last;
 	}
 	while (/[#>]\s*($cmds_regexp)\s*$/) {
@@ -209,39 +215,7 @@ sub ShowConfig {
     return(0);
 }
 
-# This routine parses "system disk show"
-sub ShowFlash {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In ShowFlash: $_" if ($debug);
-
-    while (<$INPUT>) {
-	tr/\015//d;
-	last if (/^$prompt/);
-	next if (/^(\s*|\s*$cmd\s*)$/);
-	return(1) if (/invalid command/i);
-
-	# Filesystem status:
-	#   Filesystem  Size/Used         Inodes/Used
-	#    boot        476M/164M (37%)   126K/70 (1%)
-	s/\/used\s+inodes\/used.*//i;
-	s/(\s+\w+\s+)([\d.]+.)\/\S+\s+(\S+).*/$1$2/;
-
-	# filter RAID resync messages
-	# RAID status:
-	#    boot        OK
-	#    data        OK
-	#    system      OK / RESYNC queued
-	#    swap        OK
-	s/(\s+\w+\s+\w+)\s+\/\s+resync queued/$1/i;
-
-	ProcessHistory("Version","","","# $_");
-    }
-    ProcessHistory("Version","","","#\n");
-    return(0);
-}
-
-
-# This routine parses "system hardware" & "system show"
+# This routine parses "system hardware"
 sub ShowHardware {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowHardware: $_" if ($debug);
@@ -252,20 +226,14 @@ sub ShowHardware {
 	next if (/^(\s*|\s*$cmd\s*)$/);
 	return(1) if (/invalid command/i);
 
-	# observed intermittently on T4008 running 9.2.0.
-	return(-1) if (/segmentation fault/i);
-
 	# observed intermittently on T4008 running 8.2.0.
 	return(-1) if (/error getting board version/i);
 
-	# observed intermittently on T4008 running 9.4.0.
-	return(-1) if (/error decoding result/i);
-
 	# some stupid timer error from this half-assed device
 	next if (/comsh: timer error, idle timeout will be unavailable/i);
 
-	next if (/^\s*boot time: /i);
-	next if (/^\s*load averages: /i);
+	next if (/^boot time: /i);
+	next if (/^load averages: /i);
 
 	ProcessHistory("Inventory","","","# $_");
     }
@@ -273,8 +241,7 @@ sub ShowHardware {
     return(0);
 }
 
-# This routine parses "system version", "system build-parameters",
-# "system file show"
+# This routine parses "show system version", "show system build-parameters"
 sub ShowVersion {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowVersion: $_" if ($debug);
