@@ -1,7 +1,9 @@
 package bigip;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: bigip.pm.in 3459 2016-09-08 21:37:33Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package bigip;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -55,7 +63,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.7;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -119,23 +127,6 @@ TOP: while(<$INPUT>) {
     }
 }
 
-# This routine parses a single command that returns no required info.  The
-# output is discarded.
-sub RunCommandTMSH {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In RunCommandTMSH: $_" if ($debug);
-
-    while (<$INPUT>) {
-	tr/\015//d;
-	# Needed for when our prompt changes due to our executed command (for
-	# example, after executing 'cd /')
-	$prompt = ($_ =~ /^([^#]+#)/)[0];
-	$prompt =~ s/([][}{)(\\])/\\$1/g;
-	last if (/^$prompt/);
-    }
-    return(0);
-}
-
 # This routine parses "tmsh show /sys version"
 sub ShowVersion {
     my($INPUT, $OUTPUT, $cmd) = @_;
