@@ -1,7 +1,9 @@
 package ciscowlc;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: ciscowlc.pm.in 3706 2017-07-19 14:23:59Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package ciscowlc;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -56,7 +64,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.7;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -81,6 +89,10 @@ sub inloop {
 
 TOP: while(<$INPUT>) {
 	tr/\015//d;
+	if (/^.*logout(Connection.*closed.)?$/)  {
+	    $clean_run = 1;
+	    last;
+	}
 	if (/^Error:/) {
 	    print STDOUT ("$host wlogin error: $_");
 	    print STDERR ("$host wlogin error: $_") if ($debug);
@@ -113,10 +125,6 @@ TOP: while(<$INPUT>) {
 		last TOP;
 	    }
 	}
-	if (/^.*logout(\s*connection.*closed.*)?$/i) {
-	    $clean_run = 1;
-	    last;
-	}
     }
 }
 
@@ -128,16 +136,13 @@ sub ShowConfig {
     ProcessHistory("","","","\n!--WLC Begin Config Data--!\n");
 
     while (<$INPUT>) {
-	tr/\001//d;				# filter garbage char
-	tr/\015//d;
-	tr/\020//d;
-	last if (/^$prompt/);
+        tr/\015//d;
+        tr/\020//d;
 
 	next if (/^\s*rogue ap classify/);
-	next if (/^\s*rogue (adhoc|client) (alert|unknown)/i);
+	next if (/^\s*rogue (adhoc|client) alert/);
 	next if (/^\s*interface nat-address management set -?[0-9]{4,}\./);
-	next if (/\x{7f}/);			# filter garbage line
-	
+
 	$linecnt++;
 
 	# These can not be imported, so comment them
@@ -149,7 +154,7 @@ sub ShowConfig {
 	    ProcessHistory("","","","!$_"); next;
 	}
 
-	# remove snmp community string data
+        # remove snmp community string data
 	if (/^(\s*snmp community create)/ && $filter_pwds >= 1) {
 	    ProcessHistory("","","","!$1 <removed>\n"); next;
 	}
@@ -160,6 +165,7 @@ sub ShowConfig {
 	    ProcessHistory("","","","!$1 <removed>\n"); next;
 	}
 
+	last if (/^$prompt/);
 	next if (/^(\s*|\s*$cmd\s*)$/);
 
 	$linecnt++;
@@ -191,8 +197,7 @@ sub ShowSysinfo {
 	if (/^fan status/i) { $skipprocess = 1; }
 	if (/^Number of Active Clients/) { $skipprocess = 1; }
 	if (/^OUI Classification Failure Count/) { $skipprocess = 1; }
-	if (/^(memory|cpu) (current|average)/i) { $skipprocess = 1; }
-	if (/^(mgig|internal|external) temperature/i) { $skipprocess=1; }
+	if (/^(internal|external) temperature/i) { $skipprocess=1; }
 	if (/rpm$/) { $skipprocess = 1; }
 
 	last if (/^$prompt/);
