@@ -1,11 +1,13 @@
 package dell;
 ##
+## $Id: dell.pm.in 3699 2017-07-18 13:40:55Z heas $
+##
 ## fnrancid patched to dlrancid to accomplish D-Link support
 ## adapted by: Gavin McCullagh <gmccullagh at gmail.com>
 ##             Griffith College Dublin
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -20,9 +22,15 @@ package dell;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -69,7 +77,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.7;
 
 our $proc;
 our $found_version;
@@ -101,7 +109,7 @@ sub inloop {
 TOP: while(<$INPUT>) {
 	tr/\015//d;
 	# XXX this match is not correct for DELL
-	if (/[>#]\s?exit(?:$|Connection)/) {
+	if (/[>#]\s?exit$/) {
 	    $clean_run = 1;
 	    last;
 	}
