@@ -1,7 +1,9 @@
 package iosxr;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: iosxr.pm.in 3726 2017-08-17 15:38:28Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package iosxr;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -55,7 +63,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.7;
 
 our $proc;
 our $found_env;
@@ -284,19 +292,10 @@ sub ShowVersion {
 			       "!CPU:$slave $cpu$_$slaveslot\n");
 	    }
 	    next;
-	} elsif (/^cisco (\S+(?:\sseries)?)\s+(?:\(([^)]*)\)\s+processor)/i) {
-	    $proc = $1;
-	    my($cpu) = $2;
-	    my($device) = "router";
-
-	    print STDERR "TYPE = $type\n" if ($debug);
-	    ProcessHistory("COMMENTS","keysort","A1",
-		"!Chassis type: $proc - a $proc $device\n");
-	    if (defined($cpu) && length($cpu)) {
-		ProcessHistory("COMMENTS","keysort","A3",
-			       "!CPU:$cpu\n");
-	    }
 	}
+	/^(\d+[kK]) bytes of multibus/ &&
+	    ProcessHistory("COMMENTS","keysort","B2",
+		"!Memory: multibus $1\n") && next;
 	/^(\d+[kK]) bytes of (non-volatile|NVRAM)/ &&
 	    ProcessHistory("COMMENTS","keysort","B3",
 		"!Memory: nvram $1\n") && next;
@@ -339,9 +338,10 @@ sub ShowVersion {
 }
 
 # This routine parses "admin show diag".
+# This will create arrays for hw info.
 sub AdminShowDiag {
     my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In AdminShowDiag: $_" if ($debug);
+    print STDERR "    In ShowDiag: $_" if ($debug);
 
     while (<$INPUT>) {
 	tr/\015//d;
@@ -412,42 +412,7 @@ sub AdminShowRunning {
     return(0);
 }
 
-# This routine parses "show diag".
-sub ShowDiag {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In ShowDiag: $_" if ($debug);
-
-    while (<$INPUT>) {
-	tr/\015//d;
-	last if (/^$prompt/);
-	next if (/^(\s*|\s*$cmd\s*)$/);
-	# filter the bloody cmd-line timestamp
-	next if (/^\w{3} \w{3,4} {1,3}\d{1,2} {1,2}\d{1,2}:\d+:\d+\.\d+ \S+$/);
-	return(1) if (/Line has invalid autocommand /);
-	return(1) if (/(Invalid (input|command) detected|Type help or )/i);
-	next if (/^(\e\[.\d+h)?sysadmin-vm:[^#]+# /i);			# NCS
-	return(1) if (/^(-+\^|syntax error: unknown argument)$/i);	# NCS
-	return(-1) if (/command authorization failed/i);
-
-	# skip blank lines
-	/^$/ && next;
-	# NCS junk
-	next if (/^\S+ connected from 127.0.0.1 using console /);
-	next if (/# terminal length 0$/);
-
-	s/^NODE //;
-	# wtf are these?
-	next if (/(New Deviation|UDI_VID|Board State)/);
-
-	ProcessHistory("SLOT","","","!$_");
-    }
-    ProcessHistory("SLOT","","","!\n");
-    return(0);
-}
-
-
-# This routine parses "admin show hw-module fpd location all" and
-# "show hw-module fpd" (eXR/eXR-lite).
+# This routine parses "admin show hw-module fpd location all".
 sub ShowHWfpd {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowRunning: $_" if ($debug);
@@ -466,29 +431,25 @@ sub ShowHWfpd {
 
 	# skip blank lines
 	/^$/ && next;
-
 	# NCS junk
 	next if (/^\S+ connected from 127.0.0.1 using console /);
 	next if (/# terminal length 0$/);
 
 	/^notes:/i && last;
 
-	# remove trailing WS
-	s/\s+$/\n/;
-
 	ProcessHistory("FPD","","","!$_");
     }
     ProcessHistory("FPD","","","!\n");
     return(0);
 }
 
-# This routine parses "show redundancy"
+# This routine parses "admin show redundancy"
 sub ShowRedundancy {
     my($INPUT, $OUTPUT, $cmd) = @_;
     my($slave, $slaveslot);
     print STDERR "    In ShowRedundancy: $_" if ($debug);
 
-TOP: while (<$INPUT>) {
+    while (<$INPUT>) {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^(\s*|\s*$cmd\s*)$/);
@@ -499,17 +460,19 @@ TOP: while (<$INPUT>) {
 	next if (/^(\e\[.\d+h)?sysadmin-vm:[^#]+# /i);			# NCS
 	return(1) if (/^(-+\^|syntax error: unknown argument)$/i);	# NCS
 
-	# filter reload/boot info
-	if (/^reload and boot info/i) {
-	    while (<$INPUT>) {
-		tr/\015//d;
-		last TOP if (/^$prompt/);
-		last if (/^\s*$/);
-	    }
+	if (/^Version information for secondary in slot (\d+):/) {
+	    $slave = " Slave:";
+	    $slaveslot = ", slot $1";
+	    next;
 	}
-	ProcessHistory("COMMENTS","keysort","F3", "!$_");
+
+	/^IOS .* Software \(([A-Za-z0-9_-]*)\), .*Version\s+(.*)$/ &&
+	    ProcessHistory("COMMENTS","keysort","F1",
+		"!Image:$slave Software: $1, $2\n") && next;
+	/^Compiled (.*)$/ &&
+	    ProcessHistory("COMMENTS","keysort","F3",
+		"!Image:$slave Compiled: $1\n") && next;
     }
-    ProcessHistory("COMMENTS","keysort","F3", "!\n");
     return(0);
 }
 
@@ -543,39 +506,6 @@ sub ShowInstallActive {
 
 	ProcessHistory("COMMENTS","keysort","F5","!Image: $_") && next;
     }
-    ProcessHistory("COMMENTS","keysort","F5","!\n");
-    return(0);
-}
-
-# This routine parses "show memory summary"
-sub ShowMemorySum {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In ShowMemorySum: $_" if ($debug);
-
-    # RP/0/RSP0/CPU0:r00.lab#show memory summary
-    #
-    # node:      node0_RSP0_CPU0
-    # ------------------------------------------------------------------
-    # 
-    #  Physical Memory: 27426M total (22146M available)
-    #  Application Memory : 27426M (21819M available)
-    #  Image: 4M (bootram: 0M)
-    #  Reserved: 0M, IOMem: 0M, flashfsys: 0M
-    #  Total shared window: 140M
-    while (<$INPUT>) {
-	tr/\015//d;
-	last if (/^$prompt/);
-	next if (/^(\s*|\s*$cmd\s*)$/);
-	# filter the bloody cmd-line timestamp
-	next if (/^\w{3} \w{3,4} {1,3}\d{1,2} {1,2}\d{1,2}:\d+:\d+\.\d+ \S+$/);
-	return(1) if (/Line has invalid autocommand /);
-	return(1) if (/(Invalid (input|command) detected|Type help or )/i);
-	return(-1) if (/command authorization failed/i);
-
-	/physical memory:\s+(\d+[GMKB])\s+total/i &&
-	    ProcessHistory("COMMENTS","keysort","B1",
-			   "!Memory: main $1\n") && next;
-    }
     return(0);
 }
 
@@ -614,24 +544,6 @@ sub ShowEnv {
 	    }
 	    next;
 	}
-	if (/power shelf \d+:/i) {
-	    my($sep) = 0;
-	    ProcessHistory("COMMENTS","keysort","E1","!Power: $_");
-	    while (<$INPUT>) {
-		tr/\015//d;
-		goto OUT if (/^$prompt/);
-		last if (/^altitude information/i);
-		last if (/^=+$/i && ($sep > 1));
-		$sep++ if (/^=+$/i);
-		/^total of power shelf \d+:/i && next;
-		if (/^(\s+\S+\s+(?:\S+-(?:AC|DC)|-)\s+)(\S+\s+\S+\s+\S+\s+\S+)(\s+.*)/) {
-		    $_ = sprintf("%s%-". length($2) ."s%s\n", $1, "", $3);
-		}
-		s/\s+$/\n/;
-		ProcessHistory("COMMENTS","keysort","E1","!Power: $_");
-	    }
-	    next;
-	}
 	/^Power Supply Information$/ && next;
 	/^\s*Power Module\s+Voltage\s+Current$/ && next;
 	/^\s*(Power [^:\n]+)$/ &&
@@ -644,7 +556,7 @@ sub ShowEnv {
 	    ProcessHistory("COMMENTS","keysort","E2","!Power: $1\n") && next;
     }
 OUT:
-    ProcessHistory("COMMENTS","keysort","E3","!\n");
+    ProcessHistory("COMMENTS","","","!\n");
     return(0);
 }
 
@@ -667,7 +579,6 @@ sub DirSlotN {
 	return(1) if (/^(-+\^|syntax error: unknown argument)$/i);	# NCS
 	return(1) if (/(No such device|Error Sending Request)/i);
 	return(1) if (/: path doesnot exists/i);	# NCS
-	return(1) if (/: Path does not exist/i);	# NCS
 	return(1) if (/\%Error: No such file or directory/);
 	return(1) if (/\%Error: No route to host/);
 	return(1) if (/No space information available/);
@@ -679,10 +590,29 @@ sub DirSlotN {
 	return(-1) if (/\%Error opening \S+:\S+ \(Device or resource busy\)/i);
 	return(-1) if (/command authorization failed/i);
 	return(1) if (/(Open device \S+ failed|Error opening \S+:)/);
-
-	# CSCvu27946
-	next if (/drbg_instantiate failed/);
-
+	# filter frequently changing files from IOX bootflash, hardiska,
+	# and nvram
+	if ($dev =~ /(bootflash|disk0|harddisk|nvram)/) {
+	    if (/\s(aaa|ce_switch.log|errmsg_cont|genstr_cont|temp_cont|temp_static_data|uptime_cont|volt_cont)\s*$/) {
+		# change
+		# 57          -rw-  23100       <no date>              volt_cont
+		# 614788      drwx  4096        Fri Aug 20 12:06:25 2010  temp_cont
+		# to
+		# 57          -rw-              <no date>              volt_cont
+		# 614788      drwx                                        temp_cont
+		if (/(\s*\d+\s+\S+\s+)(\d+)(\s+)(<no date> )/) {
+		    my($a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $');
+		    my($szl) = length($sz);
+		    my($fmt) = "%s%-". $szl ."s%s%s%s";
+		    $_ = sprintf($fmt, $a, "", $c, $dt, $rem);
+		} elsif (/(\s*\d+\s+\S+\s+)(\d+)(\s+)(\w+ \w+\s+\d+ \d+:\d+:\d+ \d+)/) {
+		    my($a, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $');
+		    my($szl, $dtl) = (length($sz), length($dt));
+		    my($fmt) = "%s%-". $szl ."s%s%-". $dtl ."s%s";
+		    $_ = sprintf($fmt, $a, "", $c, "", $rem);
+		}
+	    }
+	}
 	# Filter dhcp database
 	if (/dhcp_[^. ]*\.txt/) {
 	    next;
@@ -691,74 +621,23 @@ sub DirSlotN {
 	if ($proc =~ /ASR9K/ && /dlbg\.txt/) {
 	    next;
 	}
-	# filter frequently changing files from IOX bootflash, hardiska,
-	# and nvram
-	if ($dev =~ /(bootflash|disk[0-9]|harddisk|nvram)/) {
-	    if (/\s(\.python-history|aaa|\.bash_history|.sppdc)\s*$/ ||
-	        /\s(ce_switch.log\S*|cisco_support|errmsg_cont)\s*$/ ||
-	        /\s(feature_list|genstr_cont|nvgen_bkup\S*|temp_cont)\s*$/ ||
-	        /\s(temp_cont|temp_static_data|uptime_cont|volt_cont)\s*$/ ||
-	        /\s(volt_hist)\s*$/) {
-		# change
-		# 57          -rw-  23100       <no date>              volt_cont
-		# 614788      drwx  4096        Fri Aug 20 12:06:25 2010  temp_cont
-		# to
-		# -rw-              <no date>              volt_cont
-		# drwx                                        temp_cont
-		if (/\s*\d+\s+(\S+\s+)(\d+)(\s+)(<no date>)(\s+)/) {
-		    my($a, $sz, $c, $dt, $d, $rem) = ($1, $2, $3, $4, $5, $');
-		    my($szl) = length($sz);
-		    my($fmt) = "%s%-". $szl ."s%s%s%s%s";
-		    $_ = sprintf($fmt, $c, $dt, $d, $rem);
-		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $_");
-		    next;
-		} elsif (/\s*\d+\s+(\S+\s+\d+\s+)(\d+\s+\w+\s+\d+\s+\d+:\d+)/ ||
-		         /\s*\d+\s+(\S+\s+\d+\s+)(\d+\s+\w+\s+\d+\s+\d{4})/) {
-		    # XR >= 6.3; dir disk0:, but harddisk: is diff format.  wtf
-		    # drop fileno size, & date.
-		    # " 8002 drwxr-xr-x 2 4096 Jan 17 15:27 np"
-		    my($perm, $dt, $rem) = ($1, $2, $');
-		    my($dtl) = length($dt);
-		    my($fmt) = "%s%-". $dtl ."s%s";
-		    $_ = sprintf($fmt, $perm, "", $rem);
-		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $_");
-		    next;
-		} elsif (/\s*\d+\s+(\S+\s+)(\d+)(\s+)(\w+ \w+\s+\d+ \d+:\d+:\d+ \d+)/) {
-		    my($b, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $');
-		    my($szl, $dtl) = (length($sz), length($dt));
-		    my($fmt) = "%s%-". $szl ."s%s%-". $dtl ."s%s";
-		    $_ = sprintf($fmt, $b, "", $c, "", $rem);
-		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $_");
-		    next;
-		}
+	if (/.*\((\d+) (k?bytes) free\)/) {
+ 	    my($tmp) = $1;
+ 	    my($sz) = $2;
+	    $tmp *= 1024 if ($sz eq "kbytes");	# NCS summarizes in kbytes
+	
+	    if ($tmp >= (1024 * 1024 * 1024)) {
+		$tmp = int($tmp / (1024 * 1024 * 1024));
+		s/$1 $sz free/$tmp GB free/;
+	    } elsif ($tmp >= (1024 * 1024)) {
+		$tmp = int($tmp / (1024 * 1024));
+		s/$1 $sz free/$tmp MB free/;
 	    } else {
-		if (/\s*\d+\s+(\S+\s+)(\d+)(\s+)(<no date>\s+)/) {
-		    my($sz, $c, $dt, $d, $rem) = ($1, $2, $3, $4, $');
-		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $sz$c$dt$d$rem");
-		    next;
-		} elsif (/\s*\d+\s+(\S+\s+\d+\s+)(\d+\s+\w+\s+\d+\s+\d+:\d+)/ ||
-		         /\s*\d+\s+(\S+\s+\d+\s+)(\d+\s+\w+\s+\d+\s+\d{4})/) {
-		    # XR >= 6.3; dir disk0:, but harddisk: is diff format.  wtf
-		    my($perm, $dt, $rem) = ($1, $2, $');
-		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $perm$dt$rem");
-		    next;
-		} elsif (/\s*\d+\s+(\S+\s+)(\d+)(\s+)(\w+ \w+\s+\d+ \d+:\d+:\d+ \d+)/) {
-		    # XR < 6.3 & etc.
-		    my($b, $sz, $c, $dt, $rem) = ($1, $2, $3, $4, $');
-		    ProcessHistory("FLASH","keysort",$rem,"!Flash: $dev: $b$sz$c$dt$rem");
-		    next;
-		}
+		$tmp = int($tmp / 1024);
+		s/$1 $sz free/$tmp KB free/;
 	    }
 	}
 
-	# XR: 822083584 bytes total (821081600 bytes free)
-	# eXR: 990484 kbytes total (813208 kbytes free)
-	if (/^\s*(\d+ k?bytes) total\s+\((\d+ k?bytes) free\)/i) {
-	    ProcessHistory("FLASH","","","!Flash: $dev: " .
-			   diskszsummary($1, $2) . "\n");
-	    next;
-	}
-
 	ProcessHistory("FLASH","","","!Flash: $dev: $_");
     }
     ProcessHistory("","","","!\n");
@@ -890,7 +769,7 @@ sub ShowDebug {
     return(0);
 }
 
-# This routine parses "admin show install active"
+# This routine parses "admin show install summary"
 sub ShowInstallSummary {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowInstallSummary: $_" if ($debug);
@@ -920,7 +799,7 @@ sub ShowInstallSummary {
 	next if (/^\S+ connected from 127.0.0.1 using console /);
 	next if (/# terminal length 0$/);
 
-	ProcessHistory("COMMENTS", "keysort", "C15", "!Image: $_");
+	ProcessHistory("COMMENTS", "keysort", "C15", "! $_");
     }
     ProcessHistory("COMMENTS", "keysort", "C10", "!\n");
     ProcessHistory("COMMENTS", "keysort", "C19", "!\n");
@@ -957,16 +836,8 @@ sub ShowInventory {
 	    ProcessHistory("INVENTORY","","", sprintf("!%-30s %s\n", $1, $2));
 	    next;
 	}
-
-	# XR flavor:
-	# NAME: "module 0/RSP0/CPU0", DESCR: "ASR9K Route Switch Processor with 880G/slot Fabric and 32GB"
-	# PID: A9K-RSP880-SE, VID: V01, SN: FOC1911VC2S
-	#
-	# eXR flavor:
-	# NAME: "0/RSP0-Motherboard", DESCR: "Motherboard Module"
-	# PID: N/A               , VID: N/A , SN: N/A
 	# split PID/VID/SN line
-	if (/^ ?PID: (\S*)\s*, VID: (\S*)\s*,\s* SN: (\S*)\s*$/) {
+	if (/^PID: (\S*)\s*, VID: (\S*)\s*, SN: (\S*)\s*$/) {
 	    my($pid,$vid,$sn) = ($1, $2, $3);
 	    my($entries) = "";
 	    # filter <empty>, "0x" and "N/A" lines
@@ -1024,32 +895,6 @@ sub ShowLicense {
 	next if (/^\S+ connected from 127.0.0.1 using console /);
 	next if (/# terminal length 0$/);
 
-	# filter the BS from license broker
-	next if (/(renewal attempt|communication attempt):/i);
-	next if (/next registration attempt:/i);		# timestamp
-	next if (/(period used:|requested time:)/i);		# show lic feature
-	if (/(^\s*(evaluation )?period (left|remaining):\s*)\d+/i) {
-	    ProcessHistory("COMMENTS","keysort","LICENSE","! $1<limited>\n");
-	    next;
-	}
-
-	# drop license counts
-	next if (/license usage:/i);
-	if (/(.*)count status/i) {
-	    my($hdr) = $1;
-	    my($len) = length($hdr);
-
-	    $hdr =~ s/\s*$//;
-	    ProcessHistory("COMMENTS", "keysort", "C20", "! $hdr\n");
-	    while (<$INPUT>) {
-		tr/\015//d;
-		return(0) if (/^$prompt/);
-
-		s/^(.{1,$len}).*/$1/;
-		ProcessHistory("COMMENTS", "keysort", "C20", "! $_");
-	    }
-	    next;
-	}
 	ProcessHistory("COMMENTS", "keysort", "C20", "! $_");
     }
     ProcessHistory("COMMENTS", "keysort", "C20", "!\n");
@@ -1066,10 +911,6 @@ sub ShowRPL {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^(\s*|\s*$cmd\s*)$/);
-
-	# CSCvu27946
-	next if (/drbg_instantiate failed/);
-
 	# filter the bloody cmd-line timestamp
 	next if (/^\w{3} \w{3,4} {1,3}\d{1,2} {1,2}\d{1,2}:\d+:\d+\.\d+ \S+$/);
 	return(1) if /^\s*\^\s*$/;
@@ -1077,7 +918,6 @@ sub ShowRPL {
 	return(1) if (/(Invalid (input|command) detected|Type help or )/i);
 	return(1) if (/^(-+\^|syntax error: unknown argument)$/i);	# NCS
 	return(1) if (/Ambiguous command/i);
-	return(-1) if (/backing_thread:accept_file: .*/i);
 	return(-1) if (/command authorization failed/i);
 
 	ProcessHistory("COMMENTS","keysort","RPLMAX","! $_");
@@ -1129,7 +969,6 @@ REPEAT:	tr/\015//d;
 	return(0) if ($found_end);		# Only do this routine once
 	return(-1) if (/command authorization failed/i);
 	return(-1) if (/% ?configuration buffer full/i);
-	return(-1) if (/^ *drbg_instantiate failed/i);			# xr7.1
 	/^! no configuration change since last restart/i && next;
 	# skip emtpy lines at the beginning
 	if (!$linecnt && /^\s*$/) {
@@ -1235,7 +1074,7 @@ REPEAT:	tr/\015//d;
 	if (/^(ppp .* password) 7 .*/ && $filter_pwds >= 1) {
 	    ProcessHistory("","","","!$1 <removed>\n"); next;
 	}
-	if (/^(ftp client password) / && $filter_pwds >= 1) {
+	if (/^(ip ftp password) / && $filter_pwds >= 1) {
 	    ProcessHistory("","","","!$1 <removed>\n"); next;
 	}
 	if (/^( ip ospf authentication-key) / && $filter_pwds >= 1) {
@@ -1331,24 +1170,21 @@ REPEAT:	tr/\015//d;
 	}
 	# filter out any RCS/CVS tags to avoid confusing local CVS storage
 	s/\$(Revision|Id):/ $1:/;
+	# order access-lists
+	/^access-list\s+(\d\d?)\s+(\S+)\s+(\S+)/ &&
+	    ProcessHistory("ACL $1 $2","$aclsort","$3","$_") && next;
+	# order extended access-lists
+	/^access-list\s+(\d\d\d)\s+(\S+)\s+ip\s+host\s+(\S+)/ &&
+	    ProcessHistory("EACL $1 $2","$aclsort","$3","$_") && next;
+	/^access-list\s+(\d\d\d)\s+(\S+)\s+ip\s+(\d\S+)/ &&
+	    ProcessHistory("EACL $1 $2","$aclsort","$3","$_") && next;
+	/^access-list\s+(\d\d\d)\s+(\S+)\s+ip\s+any/ &&
+	    ProcessHistory("EACL $1 $2","$aclsort","0.0.0.0","$_") && next;
 	# sort ipv{4,6} access-lists
 	if ($aclfilterseq && /^ipv(4|6) access-list (\S+)\s*$/) {
 	    my($nlri, $key) = ($1, $2);
-	    my($seq, $cmd, $regexfilter);
+	    my($seq, $cmd);
 	    ProcessHistory("ACL $nlri $key","","","$_");
-	    # filter ACL contents
-	    $regexfilter = 0;
-	    if (defined($aclfilterregex) && length($aclfilterregex)) {
-		my($i);
-		my(@regexes) = split('\;', $aclfilterregex);
-		for ($i = 0; $i < ($#regexes + 1); $i++) {
-		    if ($key =~ /$regexes[$i]/) {
-			$regexfilter = 1;
-			ProcessHistory("ACL $nlri $key !", "", "",
-				       "! <$key contents removed by ACLFILTERREGEX>\n");
-		    }
-		}
-	    }
 	    while (<$INPUT>) {
 		tr/\015//d;
 		goto REPEAT if (/^$prompt/ || !/^(\s|\d|!)/);
@@ -1356,7 +1192,6 @@ REPEAT:	tr/\015//d;
 		    ProcessHistory("ACL $nlri $key !", "", "", "$_");
 		    next;
 		}
-		next if ($regexfilter);
 		# ipv4 access-list name
 		#  remark NTP
    		#  deny ipv4 host 224.0.1.1 any
