@@ -1,7 +1,9 @@
 package junos;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: junos.pm.in 3699 2017-07-18 13:40:55Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package junos;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -54,13 +62,11 @@ use strict 'vars';
 use warnings;
 require(Exporter);
 our @ISA = qw(Exporter);
-#$Exporter::Verbose=1;
+$Exporter::Verbose=1;
 
-use rancid 3.14;
+use rancid 3.7;
 
 our $ShowChassisSCB;			# Only run ShowChassisSCB() once
-our $ShowChassisFirmware;		# Only run ShowChassisFirmware() once
-
 
 @ISA = qw(Exporter rancid main);
 #our @EXPORT = qw($VERSION)
@@ -75,7 +81,6 @@ sub init {
     # add content lines and separators
     ProcessHistory("","","","#RANCID-CONTENT-TYPE: $devtype\n#\n");
 
-    $junos::ShowChassisFirmware = 0;
     0;
 }
 
@@ -89,7 +94,7 @@ TOP: while (<$INPUT>) {
 	if (/^Error:/) {
 	    print STDOUT ("$host jlogin error: $_");
 	    print STDERR ("$host jlogin error: $_") if ($debug);
-	    $clean_run = 0;
+	    $clean_run=0;
 	    last;
 	}
 	if (/System shutdown message/) {
@@ -131,7 +136,7 @@ TOP: while (<$INPUT>) {
 	    }
 	}
 	if (/>\s*quit/) {
-	    $clean_run = 1;
+	    $clean_run=1;
 	    last;
 	}
     }
@@ -148,11 +153,9 @@ sub ShowChassisClocks {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	/error: the chassis(-control)? subsystem is not r/ && return(-1);
-	/error: abnormal communication termination with / && return(-1);
-	/error: invalid xml tag / && return(-1);
 	/Couldn\'t initiate connection/ && return(-1);
 	/Unrecognized command/ && return(1);
 	/command is not valid/ && return(1);
@@ -194,7 +197,7 @@ sub ShowChassisEnvironment {
 	last if (/^$prompt/);
 	return 1 if (/^aborted!/i);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	/error: the chassis(-control)? subsystem is not r/ && return(-1);
 	/Couldn\'t initiate connection/ && return(-1);
@@ -206,7 +209,7 @@ sub ShowChassisEnvironment {
 	/ backplane temperature/ && next;
 	/(\s*Power supply.*), temperature/ &&
 		ProcessHistory("","","","# $1\n") && next;
-	/(\s*.+) +-?\d+ degrees C.*$/ &&
+	/(\s*.+) +\d+ degrees C.*$/ &&
 		ProcessHistory("","","","# $1\n") && next;
 	/(^.*\S)\s+ Spinning at .*$/ &&
 		ProcessHistory("","","","# $1\n") && next;
@@ -229,11 +232,10 @@ sub ShowChassisFirmware {
     while (<$INPUT>) {
 	tr/\015//d;
 	last if (/^$prompt/);
-	return(1) if (/^aborted!/i);
+	return 1 if (/^aborted!/i);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
-	return(0) if ($junos::ShowChassisFirmware);
 	/error: the chassis(-control)? subsystem is not r/ && return(-1);
 	/Couldn\'t initiate connection/ && return(-1);
 	/Unrecognized command/ && return(1);
@@ -241,10 +243,8 @@ sub ShowChassisFirmware {
 	/^\s+\^/ && return(1);
 	/syntax error/ && return(1);
 
-	s/\s*$//;
-	ProcessHistory("","","","# $_\n");
+	ProcessHistory("","","","# $_");
     }
-    $ShowChassisFirmware = 1;
     return(0);
 }
 
@@ -260,7 +260,7 @@ sub ShowChassisFpcDetail {
 	last if (/^$prompt/);
 	return 1 if (/^aborted!/i);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	/error: the chassis(-control)? subsystem is not r/ && return(-1);
 	/Couldn\'t initiate connection/ && return(-1);
@@ -289,7 +289,7 @@ sub ShowChassisHardware {
 	last if (/^$prompt/);
 	return 1 if (/^aborted!/i);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	/error: the chassis(-control)? subsystem is not r/ && return(-1);
 	/Couldn\'t initiate connection/ && return(-1);
@@ -315,7 +315,7 @@ sub ShowChassisRoutingEngine {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	/error: the chassis(-control)? subsystem is not r/ && return(-1);
 	/Couldn\'t initiate connection/ && return(-1);
@@ -328,8 +328,6 @@ sub ShowChassisRoutingEngine {
 	/ Slot / && ProcessHistory("","","","# $_") && next;
 	/ Current state/ && ProcessHistory("","","","# $_") && next;
 	/ Election priority/ && ProcessHistory("","","","# $_") && next;
-	s/ (DRAM\s+)\d+ \w+ \((\d+ \w+) installed\)\s*/ $1$2\n/
-		&& ProcessHistory("","","","# $_") && next;
 	/ DRAM/ && ProcessHistory("","","","# $_") && next;
 	/ Model/ && ProcessHistory("","","","# $_") && next;
 	/ Serial ID/ && ProcessHistory("","","","# $_") && next;
@@ -351,7 +349,7 @@ sub ShowChassisSCB {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	return(0) if ($junos::ShowChassisSCB);
 	/error: the chassis(-control)? subsystem is not r/ && return(-1);
@@ -385,30 +383,13 @@ sub ShowChassisAlarms {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	/Unrecognized command/ && return(1);
 	/command is not valid/ && return(1);
 	/^\s+\^/ && return(1);
 	/syntax error/ && return(1);
 
-	# filter timestamps, some oscillate
-	# 2021-11-15 06:10:09 NZDT Minor  IDP Signature usage requires a license
-	if (/^([0-9-]+ \d+:\d+:\d+ \w+) /) {
-	    my($len, $rem) = (length($1), $');
-	    my($fmt) = "%-". $len ."s %s";
-	    $_ = sprintf($fmt, "", $rem);
-	}
-
-	# filter FIB/RIB/LSP/BGP Peer Scale value, oscillates
-	# 2021-11-15 06:10:09 NZDT Minor  1049871 FIB Scales(268) require a license
-	# 2021-11-15 06:10:09 NZDT Minor  1063110 RIB Scales(269) require a license
-	# 2021-11-15 06:10:09 NZDT Minor  563 LSP Scales(270) require a license
-	# 2021-11-15 06:10:09 NZDT Minor  385 BGP Peer scales(271) require a license
-	if (/^(\s+\w+\s+)(\d+)( (?:fib|rib|lsp|bgp peer) scale.+ require a license)/i) {
-	    $_ = sprintf("%s%s%s%s", $1, "<removed>", $3, $');
-	}
-
 	ProcessHistory("","","","# $_");
     }
     return(0);
@@ -425,7 +406,7 @@ sub ShowSystemAutoinstall {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	/Unrecognized command/ && return(1);
 	/command is not valid/ && return(1);
@@ -437,36 +418,6 @@ sub ShowSystemAutoinstall {
     return(0);
 }
 
-# This routine parses "show system configuration database usage"
-# XXX this does not work with older JunOS because the unrecognized command
-#     is mangled by the cli parser and then does not match what was sent!
-#     so, this is a stand-alone function for now.
-sub ShowSystemConfDB {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In ShowSystemConfDB: $_" if ($debug);
-
-    s/^[a-z]+@//;
-    ProcessHistory("","","","# $_");
-    while (<$INPUT>) {
-	tr/\015//d;
-	($found_end = 1, last) if (/^$prompt/);
-	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
-
-	/Unrecognized command/ && return(0);
-	/command is not valid/ && return(0);
-	/^\s+\^/ && return(0);
-	/syntax error/ && return(0);
-
-	# trim fractional part of the sizes to reduce churn
-	s/\.\d+ ([GKM]B)/ $1/;
-
-	ProcessHistory("","","","# $_");
-    }
-    return(0);
-}
-
-
 sub ShowSystemCoreDumps {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowSystemCoreDumps: $_" if ($debug);
@@ -476,7 +427,6 @@ sub ShowSystemCoreDumps {
     while (<$INPUT>) {
 	tr/\015//d;
 	last if (/^$prompt/);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
 
 	/Unrecognized command/ && return(1);
 	/command is not valid/ && return(1);
@@ -501,25 +451,7 @@ sub ShowSystemLicense {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
-	return -1 if (/error: select: protocol failure /i);
-	return -1 if (/error: abnormal communication /i);
-
-	# licenses used/needed changes constantly for routing licenses.  Remove
-	# them.  example input:
-	# License usage:
-	#                                  Licenses     Licenses    Licenses    Expiry
-	#   Feature name                       used    installed      needed
-        #   fib-scale                       1049871        64000      985871    permanent
-        #   rib-scale                       1063110        64000      999110    permanent
-        #   lsp-scale                           563            0         563    invalid
-        #   bgp-peer-scale                      385            0         385    invalid
-	if (/^(\s+(?:fib|rib|lsp|bgp-peer)-\S+\s+)(\d+)(\s+\d+)(\s+\d+)(.*$)/) {
-	    my($a, $used, $avail, $need, $rem) = ($1, $2, $3, $4, $5);
-	    my($usedl, $needl) = (length($used), length($need));
-	    my($fmt) = "%s%-" . $usedl . "s%s%-" . $needl . "s%s\n";
-	    $_ = sprintf($fmt, $a, "", $avail, "", $rem);
-	}
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	# licenses used changes constantly.  distill it to a percentage.
 	# example input:
@@ -527,16 +459,12 @@ sub ShowSystemLicense {
 	#                                  Licenses     Licenses    Licenses    Expiry
 	#   Feature name                       used    installed      needed
 	#   dynamic-vpn                           1            2           0    permanent
-	#   mx5-to-mx10-upgrade                   1            0           1    30 days
-	#   mx10-to-mx40-upgrade                  1            0           1    20 hours
-	#   mx40-to-mx80-upgrade                  1            0           1    10 minutes
-	if (/^(\s+(?:VMX|dynamic|mobile|scale|service|scale-subscriber|subscriber)-\S+)(\s+)(\d+)(\s+\d+)(\s+\d+)(.*$)/) {
-	    my($a, $sp, $used, $avail, $need, $rem) = ($1, $2, $3, $4, $5, $6);
+	if (/^(\s+(?:VMX|dynamic|mobile|scale|service|subscriber)-\S+)(\s+)(\d+)(\s+\d+)(.*$)/) {
+	    my($a, $sp, $used, $avail, $rem) = ($1, $2, $3, $4, $5);
 	    my($spl, $usedl) = (length($sp), length($used));
 	    my($pcnt, $usage, $usagel);
 	    if ($avail < 1) {
 		$pcnt = ">100";
-		$usage = ">0";
 	    } else {
 		if ($filter_osc >= 2) {
 		    $usage = "--";
@@ -552,17 +480,8 @@ sub ShowSystemLicense {
 	    $usagel = length($usage) ;
 	    $spl = $spl + $usedl - $usagel;
 
-	    if ($rem =~ /^(\s+)(.*)\s*$/) {
-		my($L) = $1;
-		my($T) = $2;
-		
-		if ($filter_osc >= 1 && $T !~ /permanent/i) {   
-		    $rem = "$L<limited>";
-		}
-	    }
-
-	    my($fmt) = "%s%-" . $spl . "s%s%s%s%s\n";
-	    $_ = sprintf($fmt, $a, "", $usage, $avail, $need, $rem);
+	    my($fmt) = "%s%-" . $spl . "s%s%s%s\n";
+	    $_ = sprintf($fmt, $a, "", $usage, $avail, $rem);
 	}
 
 	/Unrecognized command/ && return(1);
@@ -586,7 +505,7 @@ sub ShowSystemLicenseKeys {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	/Unrecognized command/ && return(1);
 	/command is not valid/ && return(1);
@@ -609,7 +528,7 @@ sub ShowSystemBootMessages {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 
 	/Unrecognized command/ && return(1);
 	/command is not valid/ && return(1);
@@ -639,12 +558,9 @@ sub ShowVersion {
 	return -1 if (/select: protocol failure /i);	# fail sending cmd
 	next if (/^\s*$/);
 	next if (/^system (shutdown message from|going down )/i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
 	/error: abnormal communication termination with / && return(-1);
-	/error: could not connect to \S+ ?: no route to host/i && return(1);
-	# this happens from time to time, esp. with PHONE-HOME, and resolves
-	# on the next run.  So, just retry.
-	/: Resource deadlock avoided/ && return(-1);
+	/error: Could not connect to \S+ : No route to host / && return(-1);
 
 	/warning: .* subsystem not running - not needed by configuration/ && next;
 
@@ -676,7 +592,8 @@ sub ShowConfiguration {
 	}
 	next if (/^system (shutdown message from|going down )/i);
 	next if (/^## last commit: /i);
-	next if (/^\{(master|backup|linecard|primary|secondary)(:(node)?\d+)?\}/);
+	next if (/^\{(master|backup)(:\d+)?\}/);
+	next if (/^\{(primary|secondary)(:\d+)?\}/);
 	$lines++;
 
 	/^database header mismatch: / && return(-1);
