@@ -1,7 +1,9 @@
 package nxos;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: nxos.pm.in 3677 2017-06-21 18:39:24Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package nxos;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -55,9 +63,15 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.7;
 
 our $proc;
+our $ios;
+our $found_version;
+our $found_env;
+our $found_diag;
+our $config_register;			# configuration register value
+
 our $type;				# device model, from ShowVersion
 
 our $C0;				# output formatting control
@@ -76,6 +90,11 @@ sub import {
 # post-open(collection file) initialization
 sub init {
     $proc = "";
+    $found_version = 0;
+    $found_env = 0;
+    $found_diag = 0;
+    $config_register = undef;		# configuration register value
+
     $type = undef;			# device model, from ShowVersion
 
     $C0 = 0;				# output formatting control
@@ -117,8 +136,6 @@ TOP: while(<$INPUT>) {
 	    if (!defined($prompt)) {
 		$prompt = ($_ =~ /^([^#]+#)/)[0];
 		$prompt =~ s/([][}{)(\\])/\\$1/g;
-		# accept prompts like nexus on a ucs "routername(nexus)#"
-		$prompt =~ s/([#])$/(\\\([^)$1]+\\\))?\\$1/g;
 		print STDERR ("PROMPT MATCH: $prompt\n") if ($debug);
 	    }
 	    print STDERR ("HIT COMMAND:$_") if ($debug);
@@ -165,7 +182,7 @@ sub ShowVersion {
 	return(-1) if (/\% Permission denied/);
 	return(-1) if (/command authorization failed/i);
 
-	if (/^Cisco (Nexus|Storage Area Networking) Operating System/) { $type = "NXOS";}
+	if (/^Cisco Nexus Operating System/) { $type = "NXOS";}
 	if (/^Software$/) {
 	    while (<$INPUT>) {
 		tr/\015//d;
@@ -216,18 +233,7 @@ EndSoftware:
 	    }
 	}
 EndHardware:
-	if (/^\s+(bootflash):\s+(\d+) kB(.*)$/) {
-	    my($tmp) = int($2 / 1024);
-	    # CSCvz71586 accessing bootflash from multiple VDCs might return 0
-	    if ($2 == 0) {
-		print STDERR "ERROR: bootflash: size 0\n";
-		return(-1);
-	    }
-	    ProcessHistory("COMMENTS","keysort","B1",
-			   "!Memory: $1: $tmp MB$3\n");
-	    next;
-	}
-	if (/^\s+(slot0):\s+(\d+) kB(.*)$/) {
+	if (/^\s+(bootflash|slot0):\s+(\d+) kB(.*)$/) {
 	    my($tmp) = int($2 / 1024);
 	    ProcessHistory("COMMENTS","keysort","B1",
 			   "!Memory: $1: $tmp MB$3\n");
@@ -307,7 +313,6 @@ sub ShowRedundancy {
 	return(1) if /Line has invalid autocommand /;
 	return(1) if /(Invalid input detected|Type help or )/;
 	return(1) if (/\% Invalid command at /);
-	return(1) if (/.* command is not support/i);
 	return(-1) if (/No token match at /);	# 1000v
 	return(-1) if (/\% Permission denied/);
 	return(-1) if (/command authorization failed/i);
@@ -332,7 +337,6 @@ sub ShowEnv {
 	return(1) if /Line has invalid autocommand /;
 	return(1) if /(Invalid input detected|Type help or )/;
 	return(1) if (/\% Invalid command at /);
-	return(1) if (/ .* command is not support/i);
 	return(1) if (/No token match at /);	# 1000v
 	return(-1) if (/\% Permission denied/);
 	return(-1) if (/command authorization failed/i);
@@ -342,8 +346,6 @@ sub ShowEnv {
 	if (/(control temperature|monitor temperature)/i) {
 	    ProcessHistory("COMMENTS","","","!Env: $_");
 	    while (<$INPUT>) {
-		tr/\015//d;
-		goto EndShowEnv if (/^$prompt/);
 		if (/(.*\s+\d+\s+\d+\s+)(\d+)(.*$)/) {
 		    $_ = sprintf("%s%-". length($2)."s%s\n", $1, "", $3);
 		}
@@ -354,7 +356,6 @@ sub ShowEnv {
 	}
 	ProcessHistory("COMMENTS","","","!Env: $_");
     }
-EndShowEnv:
     ProcessHistory("COMMENTS","","","!\n");
     return(0);
 }
@@ -375,7 +376,7 @@ sub ShowEnvTemp {
 	return(-1) if (/\% Permission denied/);
 	return(-1) if (/command authorization failed/i);
 
-	s/ +$//;	# Drop trailing spaces
+	s/ +$//;	# Drop trailing ' '
 
 # Cut out CurTemp - drop the 2nd to last field.
 #--------------------------------------------------------------------
@@ -386,8 +387,6 @@ sub ShowEnvTemp {
 	if (/(control temperature|monitor temperature)/i) {
 	    ProcessHistory("COMMENTS","","","!Env: $_");
 	    while (<$INPUT>) {
-		tr/\015//d;
-		goto EndShowEnvTemp if (/^$prompt/);
 		if (/(.*\s+\d+\s+\d+\s+)(\d+)(.*$)/) {
 		    $_ = sprintf("%s%-". length($2)."s%s\n", $1, "", $3);
 		}
@@ -403,7 +402,6 @@ sub ShowEnvTemp {
 	    ProcessHistory("COMMENTS","","","!Env: $_");
 	}
     }
-EndShowEnvTemp:
     ProcessHistory("COMMENTS","","","!\n");
     return(0);
 }
@@ -466,7 +464,7 @@ sub ShowEnvPower {
 # Total Power Input (actual draw)                             161.00 W
 # Total Power Allocated (budget)                                N/A
 # Total Power Available for additional modules                  N/A  
-#
+# 
 # nexus#
 	if (/(.* +)(\d+ W +\d+ W)( +\d+ W.+)/) {
 	    $_ = sprintf("%s%-". length($2)."s%s\n", $1, "", $3);
@@ -512,7 +510,6 @@ sub ShowBoot {
 sub DirSlotN {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In DirSlotN: $_" if ($debug);
-    my($free);
 
     my($dev) = (/\s([^\s]+):/);
 
@@ -540,18 +537,14 @@ sub DirSlotN {
 	# Drop bootvar_debug log files
 	/\s+bootvar_debug\./ && next;
 
-	# Drop accounting.log*
-	/\s+accounting.log.*/ && next;
+	# Drop accounting.log
+	/\s+accounting\.log$/ && next;
 
 	# Drop vtp_debug.log and vtp_debug_old.log CDETS bug CSCuy87611
 	/\s+vtp_debug(_old)?\.log$/ && next;
 
-	# Drop bcm_mem_lock_trace.log
-	/\s+bcm_mem_lock_trace\.log$/ && next;
-
 	next if (/BufferMonitor-1HourData/);
-
-	if (/( debug_logs| log| icamsql[^.]*\.db.*)\/$/) {
+	if (/ log\/$/) {
 	    # change
 	    #         8192    Jan 08 14:05:05 2015  log/
 	    # to
@@ -564,13 +557,9 @@ sub DirSlotN {
 	    }
 	}
 
-	if (/^\s*(\d+) bytes free/i) {
-	    $free = $1;
-	    next;
-	} elsif (/^\s*(\d+) bytes used/i) {
-	    next;
-	} elsif (/^\s*(\d+) bytes total/i) {
-	    $_ = diskszsummary($1, $free, undef) . "\n";
+	if (/^\s*(\d+) bytes /) {
+	    my($tmp) = int($1 / (1024 * 1024));
+	    s/$1 bytes /$tmp MB /;
 	}
 
 	ProcessHistory("COMMENTS","","","!Flash: $dev: $_");
@@ -598,50 +587,8 @@ sub ShowModule {
 	s/(.*) \*$/$1/;	# Drop a trailing '*'
 	/^\* this terminal session/ && next;
 	s/ +$//;	# Drop trailing ' '
-
-	# filter fluctuating WWNs
-	if (/\s+World-Wide-Name.*/i) {
-	    ProcessHistory("COMMENTS","","","!Mod: $_");
-	    while (<$INPUT>) {
-		tr/\015//d;
-		goto EndShowModule if (/^$prompt/);
-		last if (/^\s*$/);
-		if (/^(\d+\s+\S+\s+\S+)\s+.*$/) {
-		    $_ = sprintf("%s\n", $1);
-		}
-		ProcessHistory("COMMENTS","","","!Mod: $_");
-	    }
-	}
 	ProcessHistory("COMMENTS","","","!Mod: $_");
     }
-EndShowModule:
-    ProcessHistory("COMMENTS","","","!\n");
-
-    return(0);
-}
-
-# This routine parses "show interface transceiver".
-sub ShowIntTransceiver {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In ShowtTransceiver: $_" if ($debug);
-
-    while (<$INPUT>) {
-	tr/\015//d;
-	return if (/^\s*\^$/);
-	last if (/^$prompt/);
-	next if (/^(\s*|\s*$cmd\s*)$/);
-	return(1) if /Line has invalid autocommand /;
-	return(1) if /(Invalid input detected|Type help or )/;
-	return(1) if (/\% Invalid command at /);
-	return(-1) if (/No token match at /);	# 1000v
-	return(-1) if (/\% Permission denied/);
-	return(-1) if (/command authorization failed/i);
-
-	# filter out oscillating data from transceivers
-	next if (/(Temperature|Current|Power|Voltage)\s+:/);
-
-	ProcessHistory("COMMENTS","","","!$_");
-    }
     ProcessHistory("COMMENTS","","","!\n");
 
     return(0);
