@@ -1,7 +1,9 @@
 package panos;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: panos.pm.in 3226 2016-01-15 21:41:54Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package panos;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -62,7 +70,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.7;
 
 @ISA = qw(Exporter rancid main);
 #XXX @Exporter::EXPORT = qw($VERSION @commandtable %commands @commands);
@@ -76,7 +84,7 @@ sub import {
 sub init {
 
     # add content lines and separators
-    ProcessHistory("","","","#RANCID-CONTENT-TYPE: $devtype\n#\n");
+    ProcessHistory("","","","!RANCID-CONTENT-TYPE: $devtype\n!\n");
 
     0;
 }
@@ -142,6 +150,8 @@ TOP: while(<$INPUT>) {
 # This routine parses "show system info"
 sub ShowInfo {
     my($INPUT, $OUTPUT, $cmd) = @_;
+    my($slot);
+
     print STDERR "    In ShowInfo:: $_" if ($debug);
 
     while (<$INPUT>) {
@@ -149,7 +159,6 @@ sub ShowInfo {
 	last if (/^$prompt/);
 	next if (/^(time:|uptime:)/);
 	next if (/^(app|av|global-protect-datafile|threat|wf-private|wildfire|url-filtering)-(version|release-date):/);
-	s/\s+$/\n/;				# remove tailing whitespaces
 
 	ProcessHistory("INFO","","","#$_");
     }
@@ -157,22 +166,6 @@ sub ShowInfo {
     return(0);
 }
 
-# This routine parses "show chassis inventory"
-sub ShowInventory {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In ShowInventory:: $_" if ($debug);
-
-    while (<$INPUT>) {
-	tr/\015//d;
-	last if (/^$prompt/);
-	return(1) if (/^Invalid syntax/);
-	s/\s+$/\n/;				# remove tailing whitespaces
-
-	ProcessHistory("INV","","","#$_");
-    }
-    ProcessHistory("INV","","","#\n");
-    return(0);
-}
 
 # This routine parses "show config running"
 sub ShowConfig {
@@ -183,18 +176,9 @@ sub ShowConfig {
 	tr/\015//d;
 	if (/^}\s*$|\[edit\]/) {
 	    $found_end = 1;
-	    ProcessHistory("","","","$_");
 	    return(1);
 	}
 
-	if (/^(\s*snmp-community-string )[^ ;]+(\s?[;{])$/ && $filter_commstr) {
-	    $_ = "#$1<removed>$2\n";
-	}
-	# filter protocol encryption keys
-	if (/^(\s*key )[^ ;]+(\s?[;{])$/ && $filter_pwds >= 1) {
-	    $_ = "#$1<removed>$2\n";
-	}
-
 	ProcessHistory("","","","$_");
 	# end of config
     }
