@@ -1,7 +1,9 @@
 package rancid;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: rancid.pm.in 3699 2017-07-18 13:40:55Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package rancid;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -53,7 +61,6 @@ use 5.010;
 use strict 'vars';
 use warnings;
 use 2.006 Socket qw(AF_INET AF_INET6 inet_pton);
-use File::Spec;
 require(Exporter);
 our @ISA = qw(Exporter);
 
@@ -69,7 +76,6 @@ our $filter_commstr;			# SNMP community string filtering
 our $filter_osc;			# oscillating data filtering mode
 our $filter_pwds;			# password filtering mode
 our $aclsort;				# ACL sorting mode
-our $aclfilterregex;			# ACL filter regex
 our $aclfilterseq;			# ACL sequence filtering mode
 our $log;				# log cmdline option
 our $debug;				# debug cmdline option
@@ -78,7 +84,6 @@ our $host;				# hostname from cmdline
 our $clean_run;				# successful run
 our $found_end;				# found end of the config
 our $timeo;				# login script timeout in seconds
-our $timeodef;				# login script timeout in seconds dflt
 our $prompt;				# device prompt regex
 
 
@@ -90,17 +95,15 @@ our @EXPORT = qw($VERSION $devtype $script $lscript @modules $inloop
 		@commandtable
 		%commands @commands $commandcnt
 		$commandstr $cmds_regexp
-		$filter_commstr $filter_osc $filter_pwds $aclsort
-		$aclfilterregex $aclfilterseq $log $debug $file $host
-		$clean_run $found_end $timeo $timeodef $prompt
-
-		bytes2human diskszsummary human2bytes
-		ipsort ipaddrval loadtype
-		keynsort keysort numerically numsort ProcessHistory rancidinit
-		RunCommand sortbyipaddr valsort which);
+		$filter_commstr $filter_osc $filter_pwds $aclsort $aclfilterseq
+		$log $debug $file $host $clean_run $found_end $timeo $prompt
+		rancidinit loadtype
+		ProcessHistory numerically keynsort keysort valsort numsort
+		ipsort ipaddrval sortbyipaddr
+		RunCommand);
 
 BEGIN {
-    $VERSION = '3.14';
+    $VERSION = '3.7';
 }
 
 # initialize common rancid parameters and handle command-line arguments.
@@ -108,7 +111,7 @@ sub rancidinit {
     my($i);
 
     if ($main::opt_V) {
-	print "rancid 3.14\n";
+	print "rancid 3.7\n";
 	exit(0);
     }
 
@@ -120,15 +123,14 @@ sub rancidinit {
 
     $log = $main::opt_l;
     $debug = $main::opt_d;
+    $devtype = $main::opt_t;
     $file = $main::opt_f;
     $host = defined($ARGV[0]) ? $ARGV[0] : "";
     $clean_run = 0;
     $found_end = 0;
-    $timeodef = 90;			# login script timeout in seconds
-    $timeo = $timeodef;			# login script timeout in seconds
+    $timeo = 90;			# login script timeout in seconds
 
     $aclsort = "ipsort";		# ACL sorting mode
-    $aclfilterregex = "";		# ACL filter regex
 
     # determine ACL sorting mode
     if (defined($ENV{"ACLSORT"}) && $ENV{"ACLSORT"} =~ /no/i) {
@@ -139,11 +141,6 @@ sub rancidinit {
     } else {
 	$aclfilterseq = "1";
     }
-    if (defined($ENV{"ACLFILTERREGEX"})) {
-	$aclfilterregex = $ENV{"ACLFILTERREGEX"};
-	# ACLFILTERSEQ is implied
-	$aclfilterseq = "1";
-    }
 
     # determine community string filtering mode
     if (defined($ENV{"NOCOMMSTR"}) && $ENV{"NOCOMMSTR"} =~ /yes/i) {
@@ -182,7 +179,6 @@ sub rancidinit {
 	print(STDERR "Too few arguments: -t option is required\n");
 	exit(1);
     }
-    $devtype = lc($main::opt_t);
 
     # make OUTPUT unbuffered if debugging
     if ($debug) { $| = 1; }
@@ -215,50 +211,17 @@ sub loadtype {
 	    $line++;
 	    chomp;
 	    next if (/^\s*$/ || /^\s*#/);
-	    my(@line) = split('\;');
-	    # check number of fields
-	    if (($#line + 1) < 3) {
-		printf(STDERR
-		       "loadtype: insufficient number of fields $#line at %s:%d\n",
-		       $file, $line);
-		return(-1);
-	    }
-	    my($type, $directive, $value) = @line;
+	    my($type, $directive, $value, $value2) = split('\;');
 	    $type =~ tr/[A-Z]/[a-z]/;
 	    $directive =~ tr/[A-Z]/[a-z]/;
 
 	    next if ($type ne $devtype);
 	    if (!$matched) {
 		$matched++;
-		printf(STDERR "loadtype: found device type %s at %s:%d\n",
-		       $devtype, $file, $line) if ($debug);
+		printf(STDERR "loadtype: found device type %s in %s\n",
+		       $devtype, $file) if ($debug);
 	    }
-	    if ($directive eq "alias") {
-		# an alias maps a name to another, like a DNS CNAME; it does
-		# NOT augment
-		printf(STDERR
-		       "loadtype: found device type %s aliased to %s\n",
-		       $devtype, $value) if ($debug);
-		if (length($value) < 1) {
-		    printf(STDERR
-			   "loadtype: type %s alias has no value at %s:%d\n",
-			   $devtype, $file, $line);
-		    close(INPUT);
-		    return(-1);
-		}
-		$value =~ tr/[A-Z]/[a-z]/;
-		if ($devtype eq $value) {
-		    printf(STDERR
-			   "loadtype: type %s aliased to itself at %s:%d\n",
-			   $devtype, $file, $line);
-		    close(INPUT);
-		    return(-1);
-		}
-		close(INPUT);
-		undef($script); undef($lscript); undef(@modules);
-		undef($inloop); undef(@commandtable); $timeo = $timeodef;
-		return(loadtype($value));
-	    } elsif ($directive eq "script") {
+	    if ($directive eq "script") {
 		$script = $value;
 	    } elsif ($directive eq "login") {
 		$lscript = $value;
@@ -267,13 +230,7 @@ sub loadtype {
 	    } elsif ($directive eq "inloop") {
 		$inloop = $value;
 	    } elsif ($directive eq "command") {
-		if (($#line + 1) < 4) {
-		    printf(STDERR
-			"loadtype: insufficient number of fields at %s:%d\n",
-			$file, $line);
-		    return(-1);
-		}
-		push(@commandtable, {$line[3], $value});
+		push(@commandtable, {$value2, $value});
 	    } elsif ($directive eq "timeout") {
 		$timeo = $value;
 	    } else {
@@ -334,28 +291,7 @@ sub loadtype {
     }
 
     if ($main::opt_C) {
-	my($cmd, @script);
-
-	if (!defined($script) || length($script) < 1) {
-	    printf(STDERR "$devtype: login script not defined\n");
-	    exit(1);
-	}
-
-	# if the first word of $script is not us (this script), exec the given
-	# script.
-	@script = split(/\s+/, $script);
-	if (which($script[0]) ne which($0)) {
-	    # -[hV] are not handled; they will have already been handled sooner.
-	    push(@script, "-d") if $debug;
-	    push(@script, "-l") if $log;
-	    push(@script, "-C") if $main::opt_C;
-	    push(@script, "-f") if $rancid::file;
-	    push(@script, $host);
-	    exec(join(" ", @script)) ||
-		printf(STDERR "exec($script[0]) failed: $!\n");
-	    exit(-1);
-	}
-
+	my($cmd);
 	if (!defined($lscript)) {
 	    printf(STDERR "$devtype: login script not defined\n");
 	    exit(1);
@@ -401,72 +337,6 @@ sub ProcessHistory {
     1;
 }
 
-# convert bytes to human-readable format (ie GB/MB/KB/etc)
-sub bytes2human {
-    my($cnt) = @_;
-
-    if ($cnt >= (1024 * 1024 * 1024)) {
-	$cnt = int($cnt / (1024 * 1024 * 1024));
-	return("$cnt GB");
-    } elsif ($cnt >= (1024 * 1024)) {
-	$cnt = int($cnt / (1024 * 1024));
-	return("$cnt MB");
-    } elsif ($cnt >= (1024)) {
-	$cnt = int($cnt / 1024);
-	return("$cnt KB");
-    } elsif ($cnt > 0) {
-	return("<1KB");
-    } else {
-	return("0 KB");
-    }
-}
-
-# summarize total flash/disk space as human-readable form and remaining space
-# as a percentage.  unknown variables should be 'undef'.  returns a string,
-# without a trailing <CR>.
-sub diskszsummary {
-    my($total, $free, $used) = @_;
-    my($pcnt);
-
-    # remove commas
-    $total = human2bytes($total) if (defined($total));
-    $free = human2bytes($free) if (defined($free));
-    $used = human2bytes($used) if (defined($used));
-
-    if (defined($free)) {
-	$pcnt = int($free / $total * 100);
-    } elsif (defined($used)) {
-	$pcnt = int(($total - $used) / $total * 100);
-    } else {
-	$total = $free + $used;
-	$pcnt = int($free / $total * 100);
-    }
-
-    $total = bytes2human($total);
-
-    return("$total total ($pcnt% free)");
-}
-
-# convert human-readable format (like "300,024 GB/MB/KB/etc") to bytes
-sub human2bytes {
-    my($cnt) = @_;
-    my($mp);
-
-    $cnt =~ s/,//g;
-
-    if ($cnt =~ /gb/i) {
-	$mp = 1024 * 1024 * 1024;
-    } elsif ($cnt =~ /mb/i) {
-	$mp = 1024 * 1024;
-    } elsif ($cnt =~ /kb/i) {
-	$mp = 1024;
-    } else {
-	$mp = 1;
-    }
-    $cnt =~ /(\d+)/;
-    return($1 * $mp);
-}
-
 sub numerically { $a <=> $b; }
 
 # keynsort(%hash) is a sort routine that will sort numerically on the
@@ -566,27 +436,8 @@ sub sortbyipaddr {
     &ipaddrval($a) cmp &ipaddrval($b);
 }
 
-# if $prog is non-FQPN, look for it in PATH and return the ABS-FQPN, else
-# just return the ABS-FQPN.
-sub which {
-    my($prog) = @_;
-    my($path);
-
-    # ABS or relative PATH (begins with /, ./, or ../)
-    if ($prog =~ /^(\/|\.\/|\.\.\/)/) {
-	return(File::Spec->rel2abs($prog));
-    }
-    for $path (split(/:/, $ENV{"PATH"})) {
-	$path = join('/', ($path, $prog));
-	if (-f $path) {
-	    return(File::Spec->rel2abs($path));
-	}
-    }
-    return($prog);
-}
-
-# This routine parses a single command that returns no required info; the
-# input is discarded.
+# This routine parses a single command that returns no required info.  The
+# output is discarded.
 sub RunCommand {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In RunCommand: $_" if ($debug);
