@@ -1,7 +1,9 @@
 package sros;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: sros.pm.in 3730 2017-09-15 18:38:42Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package sros;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -55,7 +63,7 @@ no warnings 'uninitialized';
 require(Exporter);
 our @ISA = qw(Exporter);
 
-use rancid 3.14;
+use rancid 3.7;
 
 our $proc;
 our $memoryseen;
@@ -75,11 +83,14 @@ sub init {
 
     # add content lines and separators
     ProcessHistory("","","","#RANCID-CONTENT-TYPE: $devtype\n");
+# suppress newline A0
     ProcessHistory("COMMENTS","keysort","A0","#\n");	# memory summary
+# suppress newline B0
     ProcessHistory("COMMENTS","keysort","B0","#\n");	# chassis summary
     ProcessHistory("COMMENTS","keysort","C0","#\n");	# show information
     ProcessHistory("COMMENTS","keysort","D0","#\n");    # show redundancy
     ProcessHistory("COMMENTS","keysort","E0","#\n");	# show chassis
+    ProcessHistory("COMMENTS","keysort","F0","#\n");	# show bootlog
 
     0;
 }
@@ -95,8 +106,7 @@ CMD:	if (/[#]\s?logout\s*$/) {
 	    $clean_run = 1;
 	    last;
 	}
-	if (/^Error:/ &&
-	    !(/^Error: Invalid parameter\./ || /^Error: Bad command\./)) {
+	if (/^Error:/) {
 	    print STDOUT ("$host clogin error: $_");
 	    print STDERR ("$host clogin error: $_") if ($debug);
 	    $clean_run = 0;
@@ -122,7 +132,7 @@ CMD:	if (/[#]\s?logout\s*$/) {
 		$clean_run = 0;
 		last TOP;
 	    }
-	    # filter the modified-config indicator ("*") from the line.
+	    # filter the modified config indicator from the line.
 	    /^$prompt/ && s/^[*]//;
 	    $rval = &{$commands{$cmd}}($INPUT, $OUTPUT, $cmd);
 	    delete($commands{$cmd});
@@ -139,6 +149,45 @@ CMD:	if (/[#]\s?logout\s*$/) {
     }
 }
 
+# This routine parses "file type bootlog.txt"
+sub BootLog {
+    my($INPUT, $OUTPUT, $cmd) = @_;
+    print STDERR "    In BootLog: $_" if ($debug);
+    ProcessHistory("COMMENTS","keysort","F0","# $_");
+
+    while (<$INPUT>) {
+	tr/\015//d;
+	last if (/^$prompt/);
+	next if (/^(\s*|\s*$cmd\s*)$/);
+	next if (/^\s+\^$/);
+	return(-1) if (/error: invalid parameter/i);
+	return(-1) if (/minor: cli command not allowed for this user/i);
+        # if file doesn't exist, return 0
+        return(0) if (/minor: cli could not access file/i);
+
+	/time from clock is/i && next;
+	/^(text:|executing|login:)/i && next;
+	/^File/i && next;
+	/^[-=]+$/i && next;
+	/executed [0-9,]+ lines in [0-9.]+ seconds/i && next;
+
+	if (/chassis serial number is \'(\S+)\'/i) {
+	    ProcessHistory("COMMENTS","keysort","B3",
+			   "#Chassis serial number: $1\n");
+	}
+	if (/total memory:\s+(\S+)\s+chassis type:\s+(\S+)\s+card type:\s+(\S+)/i) {
+	    next if ($memoryseen++);
+	    ProcessHistory("COMMENTS","keysort","A1",
+			   "#Total memory: $1\n");
+	    ProcessHistory("COMMENTS","keysort","B1",
+			   "#Chassis type: $2\n");
+	    ProcessHistory("COMMENTS","keysort","B2",
+			   "#Card type: $3\n");
+	}
+
+	ProcessHistory("COMMENTS","keysort","F0","# $_");
+    }
+}
 # This routine parses "show bof"
 sub ShowBOF {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -152,20 +201,14 @@ sub ShowBOF {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
-	/^INFO: CLI #\d+: Switching to the .* engine/ && next;
-	/show bof/i && next;
 
-	/[-=]+$/i && next;
+	/^[-=]+$/i && next;
 	ProcessHistory("BOF","","","# $_");
     }
 }
-
 # This routine parses "show card detail"
 sub ShowCardDetail {
     my($INPUT, $OUTPUT, $cmd) = @_;
-    my($snseen, $mcseen) = (0, 0);
     print STDERR "    In ShowCardDetail: $_" if ($debug);
     ProcessHistory("COMMENTS","keysort","E6","#\n# $_");
 
@@ -176,53 +219,15 @@ sub ShowCardDetail {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
-
-	# humanize free space
-	if (/^(\s+free space\s+:\s+)([0-9,]+\s+.*)/i) {
-	    my($preamble) = $1;
-	    my($space) = bytes2human(human2bytes($2));
-
-	    ProcessHistory("COMMENTS","keysort","E6","# $preamble$space\n");
-	    next;
-	}
 
 	# temp varies in "show card detail"
 	next if (/^(\s+Temperature\s+:)\s+\d+C/);
-	next if (/^(Config file|BOF) last (saved|modified)\s+:/ &&
-		($filter_osc >= 2));
-
-	# hardware data for the output head
-	# first serial number seen should be that of the chassis
-	if (!$snseen && /^\s+serial number\s+:\s+(\w+)/i) {
-	    ProcessHistory("COMMENTS","keysort","B1",
-			   "#Chassis serial number: $1\n");
-	    $snseen++;
-	}
-	# first memory capity seen should be hte overall total
-	if (!$mcseen && /^\s+memory capacity\s+:\s+(.*)/i) {
-	    my($hb) = bytes2human(human2bytes($1));
-	    ProcessHistory("COMMENTS","keysort","A1",
-			   "#Total memory: $hb\n");
-	    $mcseen++;
-	}
-
-	# power data
-	if (/hardware resources .power-zone/i) {
-	    while (<$INPUT>) {
-		tr/\015//d;
-		last TOP if (/^$prompt/);
-		last if (/(^\s*$|^=+)/);
-	    }
-	}
-
-	/[-=]+$/i && next;
+	next if (/^Config file last (saved|modified)\s+:/ && $filter_osc);
 
+	#/^[-=]+$/i && next;
 	ProcessHistory("COMMENTS","keysort","E6","# $_");
     }
 }
-
 # This routine parses "show card state"
 sub ShowCardState {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -236,14 +241,11 @@ sub ShowCardState {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
 
-	/[-=]+$/i && next;
+	/^[-=]+$/i && next;
 	ProcessHistory("COMMENTS","keysort","E5","# $_");
     }
 }
-
 # This routine parses "show chassis"
 sub ShowChassis {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -257,62 +259,38 @@ sub ShowChassis {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
-	/^$/i && next; # extra blank lines tr doesn't remove
 
-	/[-=]+$/i && next;
-
-	/^\s+type\s+:\s+(.*)/i &&
-	    ProcessHistory("COMMENTS","keysort","E1","# $_") &&
-	    next;
-	/^\s+serial number\s+:\s+(.*)/i &&
-	    ProcessHistory("COMMENTS","keysort","B1",
-			   "#Chassis serial number: $1\n") &&
-	    ProcessHistory("COMMENTS","keysort","E1","# $_") &&
-	    next;
+	/^[-=]+$/i && next;
 	ProcessHistory("COMMENTS","keysort","E1","# $_");
     }
-    ProcessHistory("COMMENTS","keysort","E1","#\n");
 }
-
 # This routine parses "show chassis environment"
 sub ShowChassisEnv {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowChassisEnv: $_" if ($debug);
-    ProcessHistory("COMMENTS","keysort","E3","#\n# $_");
+    ProcessHistory("COMMENTS","keysort","E2","#\n# $_");
 
-TOP: while (<$INPUT>) {
+    while (<$INPUT>) {
 	tr/\015//d;
 	last if (/^$prompt/);
 	next if (/^(\s*|\s*$cmd\s*)$/);
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
-
-	# power data
-	if (/hardware resources .power-zone/i) {
-	    while (<$INPUT>) {
-		tr/\015//d;
-		last TOP if (/^$prompt/);
-		last if (/(^\s*$|^=+)/);
-	    }
-	}
 
 	/speed/i && next;
-
-	/[-=]+$/i && next;
-	ProcessHistory("COMMENTS","keysort","E3","# $_");
+	/volts/i && next;
+	/watts/i && next;
+	/amps/i && next;
+	/^=+$/i && next;
+	ProcessHistory("COMMENTS","keysort","E2","# $_");
     }
 }
-
 # This routine parses "show chassis power-supply"
 sub ShowChassisPS {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowChassisPS: $_" if ($debug);
-    ProcessHistory("COMMENTS","keysort","E4","#\n# $_");
+    ProcessHistory("COMMENTS","keysort","F3","#\n# $_");
 
     while (<$INPUT>) {
 	tr/\015//d;
@@ -320,23 +298,17 @@ sub ShowChassisPS {
 	next if (/^(\s*|\s*$cmd\s*)$/);
 	next if (/^\s+\^$/);
 	return(0) if (/error: invalid parameter/i);	# cmd for 7750 SR only
-	/\^+/i && next;
-	return(0) if (/minor: .* unknown element/i);    # cmd for 7750 SR only
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
 
-	/[-=]+$/i && next;
-	/input voltage/i && next;
-	ProcessHistory("COMMENTS","keysort","E4","# $_");
+	/^=+$/i && next;
+	ProcessHistory("COMMENTS","keysort","F3","# $_");
     }
 }
-
 # This routine parses "show chassis power-management"
 sub ShowChassisPM {
     my($INPUT, $OUTPUT, $cmd) = @_;
     print STDERR "    In ShowChassisPM: $_" if ($debug);
-    ProcessHistory("COMMENTS","keysort","E5","#\n# $_");
+    ProcessHistory("COMMENTS","keysort","E4","#\n# $_");
 
     while (<$INPUT>) {
 	tr/\015//d;
@@ -344,20 +316,15 @@ sub ShowChassisPM {
 	next if (/^(\s*|\s*$cmd\s*)$/);
 	next if (/^\s+\^$/);
 	return(0) if (/error: invalid parameter/i);	# cmd for 7950 XRS only
-	/\^+/i && next;
-	return(0) if (/minor: .* unknown element/i);    # cmd for 7950 XRS only
 	return(-1) if (/minor: cli command not allowed for this user/i);
-        # context lines
-	/^\[[^]]*]$/i && next;
 
 	/volts/i && next;
 	/watts/i && next;
 	/amps/i && next;
-	/[-=]+$/i && next;
-	ProcessHistory("COMMENTS","keysort","E5","# $_");
+	/^=+$/i && next;
+	ProcessHistory("COMMENTS","keysort","E4","# $_");
     }
 }
-
 # This routine parses "show debug"
 sub ShowDebug {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -371,93 +338,10 @@ sub ShowDebug {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
-	/^INFO: CLI #\d+: Switching to the .* engine/ && next;
-	/show debug/i && next;
 
 	ProcessHistory("","","","$_");
     }
 }
-
-# This routine parses "show mda detail"
-sub ShowMDA {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In ShowMDA: $_" if ($debug);
-    ProcessHistory("COMMENTS","keysort","E2","# $_");
-
-TOP: while (<$INPUT>) {
-	tr/\015//d;
-	last if (/^$prompt/);
-	next if (/^(\s*$cmd\s*)$/);
-	next if (/^\s+\^$/);
-	return(-1) if (/error: invalid parameter/i);
-	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
-	/^$/i && next; # extra blank lines tr doesn't remove
-
-	/[-=]+$/i && next;
-	/Temperature/i && next;
-
-	# trim power info
-	# Hardware Resources (Power-Zone 1)
-	#     Voltage
-	#         Minimum                   :    54.88 Volts  (06/23/2022 15:53:39)
-	#         Current                   :    54.91 Volts 
-	#         Peak                      :    54.95 Volts  (04/28/2022 16:28:34)
-	#     Wattage
-	#         ....
-	#         Max Required              :  2400.00 Watts 
-	#     Amperage
-	#         ....
-	if (/hardware resources .power-zone/i) {
-	    while (<$INPUT>) {
-		tr/\015//d;
-		last TOP if (/^$prompt/);
-		last if (/(^\s*$|^=+)/);
-	    }
-	}
-
-	ProcessHistory("COMMENTS","keysort","E2","# $_");
-    }
-}
-
-# This routine parses "show port detail"
-sub ShowPortDetail {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    my($text);
-    print STDERR "    In ShowPortDetail: $_" if ($debug);
-    ProcessHistory("COMMENTS","keysort","E6","#\n# $_");
-
-TOP: while (<$INPUT>) {
-	tr/\015//d;
-	last if (/^$prompt/);
-	next if (/^(\s*|\s*$cmd\s*)$/);
-	next if (/^\s+\^$/);
-	return(-1) if (/error: invalid parameter/i);
-	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
-
-	# accumulate interface name and description; only print if it has a xcvr
-	/^(Interface\s+:\s+\S+)/ && ($text = "# $1\n" . $text);
-	/^(Description\s+:\s+)/ && ($text = "# $_");
-	if (/^transceiver status\s*:\s*/i) {
-	    next TOP if (/not-equipped/);
-	    ProcessHistory("COMMENTS","keysort","E8","$text");
-	    while (<$INPUT>) {
-		tr/\015//d;
-		last TOP if (/^$prompt/);
-		last if (/(^\s*$|^[-=]+)/);
-		ProcessHistory("COMMENTS","keysort","E8","# $_");
-	    }
-	}
-
-	/[-=]+$/i && next;
-    }
-}
-
 # This routine parses "show redundancy synchronization"
 sub ShowRedundancy {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -471,12 +355,11 @@ sub ShowRedundancy {
 	next if (/^\s+\^$/);
         # not on 7210 SAS, return 0
 	return(0) if (/error: invalid parameter/i);
-	return(0) if (/minor: .* synchronization is only supported/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
 
-	/[-=]+$/i && next;
+	/synchronization .* only supported on dual/i && return(0);
+
+	/^[-=]+$/i && next;
 	/standby up time/i && next;
 	/last config file sync time/i && next;
 	/last boot env sync time/i && next;
@@ -486,7 +369,6 @@ sub ShowRedundancy {
 	ProcessHistory("COMMENTS","keysort","D2","# $_");
     }
 }
-
 # This routine parses "show system information"
 sub ShowSystemInfo {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -501,23 +383,14 @@ sub ShowSystemInfo {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	/^\[[^]]*]$/i && next;
 
-	/[-=]+$/i && next;
+	/^[-=]+$/i && next;
 	/system up time/i && next;
-	# User Last Modified     : someuname
-	# Time Last Modified     : 2018/05/29 09:15:32
-	/(user|time) last modified/i && ($filter_osc >= 2) && next;
-	# Changes Since Last Save: Yes
-	/changes since last save/i && ($filter_osc >= 2) && next;
-	/time last saved/i && ($filter_osc >= 2) && next;
-
-
+	/time last saved/i && next;
 	if (/system type\s+:\s+(.*)/i) {
 	    $proc = $1;
 	    ProcessHistory("COMMENTS","keysort","B4",
-			   "#Chassis type: $proc\n");
+			   "#System type: $proc\n");
 	}
 	if (/system version\s+:\s+(.*)/i) {
 	    $proc = $1;
@@ -527,7 +400,6 @@ sub ShowSystemInfo {
 	ProcessHistory("COMMENTS","keysort","C1","# $_");
     }
 }
-
 # This routine parses "admin display-config index"
 sub WriteTermIndex {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -541,20 +413,17 @@ sub WriteTermIndex {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	#/^\[[^]]*]$/i && next;
 
 	/# (timos-|all rights reserved|built on)/i && next;
-	/# (Generated|Last modified|Last saved) /i && next;
+	/# Generated /i && next;
 
 	/^#-+$/i && next;
 	s/echo \"(.*)\"/# $1/i;
 
-	next if (/^# finished /i);
+	next if (/^# finished \S{3} \S{3} /i);
 	ProcessHistory("","","","$_");
     }
 }
-
 # This routine parses "admin display-config"
 sub WriteTerm {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -568,11 +437,9 @@ sub WriteTerm {
 	next if (/^\s+\^$/);
 	return(-1) if (/error: invalid parameter/i);
 	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	#/^\[[^]]*]$/i && next;
 
 	/# (timos-|all rights reserved|built on)/i && next;
-	/# (Generated|Last modified|Last saved) /i && next;
+	/# Generated /i && next;
 
 	/^#-+$/i && next;
 	s/echo \"(.*)\"/# $1/i;
@@ -602,74 +469,7 @@ sub WriteTerm {
 	}
 
 	# end of config.
-	if (/^# finished /i) {
-	    $found_end = 1;
-	    return(0);
-	}
-	ProcessHistory("","","","$_");
-    }
-
-    return(0);
-}
-
-# This routine parses "admin show configuration" in the MD-CLI
-sub WriteTermMD {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In WriteTermMD: $_" if ($debug);
-    ProcessHistory("","","","#\n# $_");
-    my($linecnt) = 0;
-
-    while (<$INPUT>) {
-	tr/\015//d;
-	last if (/^$prompt/);
-	next if (/^(\s*|\s*$cmd\s*)$/);
-	next if (/^\s+\^$/);
-	return(-1) if (/error: invalid parameter/i);
-	return(-1) if (/minor: cli command not allowed for this user/i);
-	# context lines
-	#/^\[[^]]*]$/i && next;
-
-	/# (timos-|all rights reserved|built on)/i && next;
-	/# Generated /i && next;
-
-	/^#-+$/i && next;
-	s/echo \"(.*)\"/# $1/i;
-
-	$linecnt++;
-
-	# password/community filtering
-	if (/^(\s+community) "[^"]*" /) {
-	    if ($filter_commstr) {
-		ProcessHistory("SNMPSERVERCOMM","","", "#$1 <removed> $'") &&
-		next;
-	    } else {
-		ProcessHistory("SNMPSERVERCOMM","","","$_") && next;
-	    }
-	}
-	if (/^(\s+trap-target\s+.*)\s+(notify-community)\s+("\S+")/) {
-	    if ($filter_commstr) {
-		ProcessHistory("","","","#$1 $2 <removed>$'") && next;
-	    } else {
-		ProcessHistory("","","","$_") && next;
-	    }
-	}
-	if (/^(\s+password)\s+("\$\S+")/) {
-	    if ($filter_pwds >= 2) {
-		ProcessHistory("","","","#$1 <removed>$'") && next;
-	    } else {
-		ProcessHistory("","","","$_") && next;
-	    }
-	}
-	if (/^(\s+authentication-key)\s+("\S+"\s+hash2)/) {
-	    if ($filter_pwds >= 1) {
-		ProcessHistory("","","","#$1 <removed>$'") && next;
-	    } else {
-		ProcessHistory("","","","$_") && next;
-	    }
-	}
-
-	# end of config.
-	if ((/^(# finished |\[\]\s*$)/i) && $linecnt > 5) {
+	if (/^# finished \S{3} \S{3} /i) {
 	    $found_end = 1;
 	    return(0);
 	}
