@@ -1,7 +1,9 @@
 package wavesvros;
 ##
-## rancid 3.14
-## Copyright (c) 1997-2022 by Henry Kilmer and John Heasley
+## $Id: wavesvros.pm.in 3723 2017-07-31 21:27:57Z heas $
+##
+## rancid 3.7
+## Copyright (c) 1997-2017 by Henry Kilmer and John Heasley
 ## All rights reserved.
 ##
 ## This code is derived from software contributed to and maintained by
@@ -16,9 +18,15 @@ package wavesvros;
 ## 2. Redistributions in binary form must reproduce the above copyright
 ##    notice, this list of conditions and the following disclaimer in the
 ##    documentation and/or other materials provided with the distribution.
-## 3. Neither the name of RANCID nor the names of its
+## 3. All advertising materials mentioning features or use of this software
+##    must display the following acknowledgement:
+##        This product includes software developed by Henry Kilmer and John
+##        Heasley and its contributors for RANCID.
+## 4. Neither the name of RANCID nor the names of its
 ##    contributors may be used to endorse or promote products derived from
 ##    this software without specific prior written permission.
+## 5. It is requested that non-binding fixes and modifications be contributed
+##    back to RANCID.
 ##
 ## THIS SOFTWARE IS PROVIDED BY Henry Kilmer, John Heasley AND CONTRIBUTORS
 ## ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
@@ -54,9 +62,9 @@ use strict 'vars';
 use warnings;
 require(Exporter);
 our @ISA = qw(Exporter);
-#$Exporter::Verbose=1;
+$Exporter::Verbose=1;
 
-use rancid 3.14;
+use rancid 3.7;
 
 @ISA = qw(Exporter rancid main);
 #our @EXPORT = qw($VERSION)
@@ -139,29 +147,9 @@ TOP: while (<$INPUT>) {
     }
 }
 
-# This routine parses a few commands generically
-sub GenericCmd {
-    my($INPUT, $OUTPUT, $cmd) = @_;
-    print STDERR "    In GenericCmd: $_" if ($debug);
-
-    # include the command
-    s/^[a-z]+@//; s/^([^ ]+)\*([>#])/$1$2/;
-    ProcessHistory("","","","! $_");
-    while (<$INPUT>) {
-	tr/\015//d;
-	last if (/^$prompt/);
-
-	ProcessHistory("","","","! $_");
-    }
-    ProcessHistory("","","","!\n");
-
-    return(0);
-}
-
 # This routine parses "chassis show"
 sub ShowChassis {
     my($INPUT, $OUTPUT, $cmd) = @_;
-    my($PSW) = 0;
     print STDERR "    In ShowChassisClocks: $_" if ($debug);
 
     # include the command
@@ -172,36 +160,21 @@ sub ShowChassis {
 	last if (/^$prompt/);
 	/no matching entry found/ && return(-1);	# unknown cmd
 
-	# skip fan status/chassis power draw
-	if (/(cfu fan status|chassis power summary)/i) {
+	# skip fan status
+	if (/CFU FAN STATUS/) {
 	    while (<$INPUT>) {
 		tr/\015//d;
 		return(-1) if (/^$prompt/);
 		last if (/^\s*$/);
 	    }
 	}
-	# filter PS wattage from power supply status
-	if (/power supply status/i) {
-	    ProcessHistory("","","","! $_");
-	    while (<$INPUT>) {
-		tr/\015//d;
-		goto EndShowChassis if (/^$prompt/);
-		$PSW = 1 if (/power \(w\)/i);
-		if ($PSW && /^((?:\|[^|]+){6,7})\|\s+(?:[0-9.]+ \|)/) {
-		    ProcessHistory("","","","! $1|\n");
-		} else {
-		    ProcessHistory("","","","! $_");
-		}
-		last if (/^\s*$/);
-	    }
-	}
 
 	ProcessHistory("","","","! $_");
     }
-EndShowChassis:
     return(0);
 }
 
+
 # This routine parses "software show"
 sub ShowVersion {
     my($INPUT, $OUTPUT, $cmd) = @_;
@@ -260,7 +233,7 @@ sub WriteTerm {
 #	    ProcessHistory("","","","#$1<removed>$'");
 #	    next;
 #	}
-	if (/(user (create|set) user \S+ access-level \S+ secret )/ &&
+	if (/(user create user \S+ access-level \S+ secret) / &&
 	    $filter_pwds >= 1) {
 	    ProcessHistory("","","","!$1<removed>\n");
 	    next;
